@@ -14,22 +14,25 @@
 #' \item{stats}{Useful overview of detected DIF items, responsible variables and executed splits}
 #' \item{nosplits}{Total number of executed splits during the estimation procedure}
 #' 
-#' @author Moritz Berger <moritz.berger@stat.uni-muenchen.de> \cr \url{http://www.statistik.lmu.de/~mberger/}
+#' @author Moritz Berger <moritz.berger@imbie.uni-bonn.de> \cr \url{http://www.imbie.uni-bonn.de/personen/dr-moritz-berger/}
 #' 
 #' @references 
-#' Berger, Moritz and Tutz, Gerhard (2015): Detection of Uniform and Non-Uniform Differential Item Functioning 
-#' by Item Focussed Trees, Cornell University Library, arXiv:1511.07178
+#' Berger, Moritz and Tutz, Gerhard (2016): Detection of Uniform and Non-Uniform Differential Item Functioning 
+#' by Item Focussed Trees, Journal of Educational and Behavioral Statistics 41(6), 559-592.
 #' 
-#' Tutz, Gerhard and Berger, Moritz (2015): Item Focused Trees for the Identification of Items
-#' in Differential Item Functioning, Psychometrika, published online, DOI: 10.1007/s11336-015-9488-3 
+#' Bollmann, Stella, Berger, Moritz & Tutz, Gerhard (2018): Item-Focussed Trees for the Detection 
+#' of Differential Item Functioning in Partial Credit Models, Educational and Psychological Measurement 78(5), 781-804.
+#' 
+#' Tutz, Gerhard and Berger, Moritz (2016): Item focussed Trees for the Identification of Items
+#' in Differential Item Functioning, Psychometrika 81(3), 727-750. 
 #' 
 #' @seealso \code{\link[DIFtree]{DIFtree}}, \code{\link[DIFtree]{plot.DIFtree}}, \code{\link[DIFtree]{predict.DIFtree}}
 #' 
 #' @examples 
-#' data(data_sim)
+#' data(data_sim_Rasch)
 #'  
-#' Y <- data_sim[,1]
-#' X <- data_sim[,-1]
+#' Y <- data_sim_Rasch[,1]
+#' X <- data_sim_Rasch[,-1]
 #'  
 #' \dontrun{
 #'  
@@ -49,7 +52,7 @@ function(object, # object of class DIFtree
   
   to_return <- list(call=object$call)
   
-  model <- which(c("Rasch","Logistic")==object$model)
+  model <- which(c("Rasch","Logistic","PCM")==object$model)
   if(model==2){
     type <- which(c("udif","dif","nudif")==object$type)
   } else{
@@ -81,7 +84,7 @@ print.summary.DIFtree <-
   function(x, # object of class summary.DIFtree 
            ...){
     
-    model <- which(c("Rasch","Logistic")==x$model)
+    model <- which(c("Rasch","Logistic","PCM")==x$model)
     if(model==2){
       type <- which(c("udif","dif","nudif")==x$type)
     } else{
@@ -90,9 +93,13 @@ print.summary.DIFtree <-
     cat("\n")
     if(model==1){
       cat("Item focussed Trees based on the Rasch Model:\n")
-    } else{
+    }
+    if(model==2){
       cat("Item focussed Trees based on the Logistic Regression Approach",c("(uniform","(uniform and non-uniform","(non-uniform")[type],"DIF):\n")
     }
+    if(model==3){
+      cat("Item focussed Trees based on the PCM:\n")
+    }
     cat("\n")
     cat("Call:\n",paste(deparse(x$call)),"\n")
     cat("\n")
